﻿/*******************************************************************************
File        : Program.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/05/16 TPR Created
*******************************************************************************/
using System;
using Wiker.WIDatabase;
using System.Collections.ObjectModel;
using System.Text;

namespace MultipleJoin
{
   /*******************************************************************************
   Class        : Program
   Description  : 
   --------------------------------------------------------------------------------
   History:
   2011/05/16 TPR Created
   *******************************************************************************/
   class Program
   {      
      /*******************************************************************************
      Function    : Main()
      Description : 
      Parameters  : string[] args - 
      Returns     : void
      --------------------------------------------------------------------------------
      History:
      2011/05/16 TPR Created
      *******************************************************************************/
      static void Main(string[] args)
      {
         WIDatabase WIDB;
         string ColumnDataStr;
         int ColumnDataInt;
         bool ColumnDataBool;
         StringBuilder StrB;
         CDatabaseInfo DBInfo;
         Collection<CCondition> Conditions;

         /* Create DatabaseInfo object with login info  */
         DBInfo = new CDatabaseInfo();
         DBInfo.DatabaseType = eDatabaseType.SQLite;
         DBInfo.Location =  "\\WIDatabase\\Samples";
         DBInfo.DBName = "SQLite.db3";         
         DBInfo.Password = "";
         DBInfo.Port = 0;
         DBInfo.Username = "";

         /* Create WIDatabase object */
         WIDB = new WIDatabase(DBInfo);
         
         /* Calling Select.Clear() ensures we starting with a new select statement. */
         WIDB.Search.Clear();

         /* The Column Class is used to choose columns to be returned */
         WIDB.Search.Column("tblCompany", "CompanyID");
         WIDB.Search.Column("tblCompany", "AddressID");
         WIDB.Search.Column("Name");
         WIDB.Search.Column("LogoID");
         WIDB.Search.Column("WebSite");
         WIDB.Search.Column("Active");
         WIDB.Search.Column("Address1");
         WIDB.Search.Column("Address2");
         WIDB.Search.Column("City");
         WIDB.Search.Column("State");
         WIDB.Search.Column("ZipCode");
         WIDB.Search.Column("P1", "Number", "CompanyPhone");
         WIDB.Search.Column("P2", "Number", "CompanyFax");

         /* Select.Table: The 'Main' table from which the data will originate */
         WIDB.Search.Table("tblCompany");
         WIDB.Search.Condition("tblCompany", "CompanyID", eOperator.Equal, 15);

         /* Select.Join: Used to 'connect' related tables. */
         WIDB.Search.Join("tblAddress", "AddressID", eOperator.Equal, "tblCompany", "AddressID", eJoinType.Left);
         WIDB.Search.Join("tblImage", "ImageID", eOperator.Equal, "tblCompany", "LogoID", eJoinType.Left);

         Conditions = new Collection<CCondition>();
         Conditions.Add(new CCondition("P1", "CompanyID", eOperator.Equal, "tblCompany", "CompanyID"));
         Conditions.Add(new CCondition(eLogic.AND));
         Conditions.Add(new CCondition("P1", "Type", eOperator.Equal, 2));
         WIDB.Search.Join("tblPhone", "P1", Conditions, eJoinType.Left);

         Conditions = new Collection<CCondition>();
         Conditions.Add(new CCondition("P2", "CompanyID", eOperator.Equal, "tblCompany", "CompanyID"));
         Conditions.Add(new CCondition(eLogic.AND));
         Conditions.Add(new CCondition("P2", "Type", eOperator.Equal, 4));
         WIDB.Search.Join("tblPhone", "P2", Conditions, eJoinType.Left);                 

         /* Select.Execute() prepares the statement to be sent to the Database */
         WIDB.Search.Execute();

         Console.WriteLine("| CompanyID | AddressID | Name | LogoID | WebSite | Active | Address1 | Address2 | City | State | ZipCode | CompanyPhone | CompanyFax |");

         /* Select.Read() reads the next row from the returned data */
         while (WIDB.Search.Read())
            {
            StrB = new StringBuilder();

            /* Select.Get obtains the value of the named column via an out parameter */
            WIDB.Search.Get("CompanyID", out ColumnDataInt);
            StrB.AppendFormat("| {0} ",ColumnDataInt);

            WIDB.Search.Get("AddressID", out ColumnDataInt);
            StrB.AppendFormat("| {0} ",ColumnDataInt);

            WIDB.Search.Get("Name", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("LogoID", out ColumnDataInt);
            StrB.AppendFormat("| {0} ",ColumnDataInt);

            WIDB.Search.Get("WebSite", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("Active", out ColumnDataBool);
            StrB.AppendFormat("| {0} ",ColumnDataBool);

            WIDB.Search.Get("Address1", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("Address2", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("City", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("State", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("ZipCode", out ColumnDataStr);                                                
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("CompanyPhone", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("CompanyFax", out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            Console.WriteLine(StrB.ToString());
            }

         /* Good practice is to close the DB when finished */
         WIDB.Close();
      }
   }/* End Class */
}/* End NameSpace */
