﻿/*******************************************************************************
File        : MainForm.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using System.Drawing;
using Wiker.WIDatabase;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm : Form
{
const string NEW_COMPANY = "<New Company>";
const string NEW_PERSON = "<New Person>";

Image CutPasteImage;

public bool UseSELECT;

/*******************************************************************************
Constructor : MainForm()
Description : 
Parameters  : None
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public MainForm()
{
InitializeComponent();

ClearScreen();

SETTINGS.DatabaseFailureCallBack = DatabaseFailureCallBack;
SETTINGS.DebugLogCallBack = DebugLogCallBack;

UseSELECT = false;
radioWIDatabase.Checked = true;
radioSQLite.Checked = true;
}
/*******************************************************************************
Function    : DatabaseFailureCallBack()
Description : 
Parameters  : eDBErrorCodes errorCode - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/07/05 WLM Created
*******************************************************************************/
bool DatabaseFailureCallBack(eDBErrorCodes errorCode)
{
MessageBox.Show(string.Format("DBFailureCallback {0}", errorCode.ToString()));
return(true);
}
/*******************************************************************************
Function    : DebugLogCallBack()
Description : 
Parameters  : string message - 
            : Exception ex - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/07/05 WLM Created
*******************************************************************************/
void DebugLogCallBack(string message, Exception ex)
{
MessageBox.Show(string.Format("{0}\n{1}", message, ex.Message));
}
/*******************************************************************************
Function    : radioWIDatabase_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/13 WLM Created
*******************************************************************************/
private void radioWIDatabase_Click(object sender, EventArgs e)
{
if (!radioWIDatabase.Focused)
   return;

UseSELECT = false;

ClearScreen();
LoadScreen();
}
/*******************************************************************************
Function    : radioSELECT_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/13 WLM Created
*******************************************************************************/
private void radioSELECT_Click(object sender, EventArgs e)
{
if (!radioSELECT.Focused)
   return;

UseSELECT = true;

ClearScreen();
LoadScreen();
}
/*******************************************************************************
Function    : MainForm_Load()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
private void MainForm_Load(object sender, EventArgs e)
{
LoadScreen();
}
/*******************************************************************************
Function    : LoadScreen()
Description : 
Parameters  : None
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
void LoadScreen()
{
if (!EveryExists())
   return;

LoadCompanyCombos();
LoadPersonCombo();
}
/*******************************************************************************
Function    : buttonCreate_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
private void buttonCreate_Click(object sender, EventArgs e)
{
if (!CreateTables())
   return;

LoadScreen();

MessageBox.Show("Tables created");
}
/*******************************************************************************
Function    : radioWIDatabase_CheckedChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
private void radioWIDatabase_CheckedChanged(object sender, EventArgs e)
{
UseSELECT = !radioWIDatabase.Checked;
}
/*******************************************************************************
Function    : radioSELECT_CheckedChanged()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
private void radioSELECT_CheckedChanged(object sender, EventArgs e)
{
UseSELECT = radioSELECT.Checked;
}
/*******************************************************************************
Function    : buttonDROP_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/04/27 WLM Created
*******************************************************************************/
private void buttonDROP_Click(object sender, EventArgs e)
{
if (DropTables())
   MessageBox.Show("Tables Droped");
}
/*******************************************************************************
Function    : GetDBInfo()
Description : 
Parameters  : None
Returns     : CDatabaseInfo
--------------------------------------------------------------------------------
History:
2011/05/09 WLM Created
*******************************************************************************/
public CDatabaseInfo GetDBInfo()
{
CDatabaseInfo DatabaseInfo;

DatabaseInfo = new CDatabaseInfo();

if (radioMySql.Checked)
   {
   DatabaseInfo.DatabaseType = eDatabaseType.MySql;
   DatabaseInfo.Location = textMySqlLocation.Text.Trim();
   DatabaseInfo.DBName = textMySqlName.Text.Trim();

   if (!int.TryParse(textMySqlPort.Text, out DatabaseInfo.Port))
      DatabaseInfo.Port = 0;

   DatabaseInfo.Username = textMySqlUsername.Text.Trim();
   DatabaseInfo.Password = textMySqlPassword.Text.Trim();
   }

else
if (radioSql.Checked)
   {
   DatabaseInfo.DatabaseType = eDatabaseType.SQL;
   DatabaseInfo.Location = textSqlLocation.Text.Trim();
   DatabaseInfo.DBName = textSqlName.Text.Trim();

   if (!int.TryParse(textSqlPort.Text, out DatabaseInfo.Port))
      DatabaseInfo.Port = 0;

   DatabaseInfo.Username = textSqlUsername.Text.Trim();
   DatabaseInfo.Password = textSqlPassword.Text.Trim();
   }

else
if (radioSQLite.Checked)
   {
   DatabaseInfo.DatabaseType = eDatabaseType.SQLite;
   DatabaseInfo.Location = textSQLiteLocation.Text.Trim();
   DatabaseInfo.DBName = textSQLiteName.Text.Trim();

   DatabaseInfo.Port = 0;
   DatabaseInfo.Username = "";
   DatabaseInfo.Password = textSQLitePassword.Text.Trim();
   }

else
   {
   DatabaseInfo.DatabaseType = eDatabaseType.None;
   MessageBox.Show("Invalid Database Type");
   return(null);
   }

return(DatabaseInfo);
}
/*******************************************************************************
Function    : GetDBName()
Description : 
Parameters  : eDatabaseType databaseType - 
Returns     : string
--------------------------------------------------------------------------------
History:
2011/05/10 WLM Created
*******************************************************************************/
public string GetDBName(eDatabaseType databaseType)
{
switch (databaseType)
   {
   case eDatabaseType.MySql:
      return(textMySqlLocation.Text.Trim());

   case eDatabaseType.SQL:
      return(textSqlLocation.Text.Trim());

   case eDatabaseType.SQLite:
      return(textSQLiteLocation.Text.Trim());
   }

return("");
}
/*******************************************************************************
Function    : EveryExists()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/06 WLM Created
*******************************************************************************/
bool EveryExists()
{
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (!WIDB.Table.Exists("tblAddress"))
   return(false);

if (!WIDB.Table.Exists("tblCompany"))
   return(false);

if (!WIDB.Table.Exists("tblImage"))
   return(false);

if (!WIDB.Table.Exists("tblPerson"))
   return(false);

if (!WIDB.Table.Exists("tblPhone"))
   return(false);

return(true);
}
/*******************************************************************************
Function    : radioSQLite_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/10 WLM Created
*******************************************************************************/
private void radioSQLite_Click(object sender, EventArgs e)
{
ClearScreen();
LoadScreen();
}
/*******************************************************************************
Function    : radioSql_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/10 WLM Created
*******************************************************************************/
private void radioSql_Click(object sender, EventArgs e)
{
ClearScreen();
LoadScreen();
}
/*******************************************************************************
Function    : radioMySql_Click()
Description : 
Parameters  : object sender - 
            : EventArgs e - 
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/10 WLM Created
*******************************************************************************/
private void radioMySql_Click(object sender, EventArgs e)
{
ClearScreen();
LoadScreen();
}
/*******************************************************************************
Function    : ClearScreen()
Description : 
Parameters  : None
Returns     : void
--------------------------------------------------------------------------------
History:
2011/05/10 WLM Created
*******************************************************************************/
void ClearScreen()
{
ClearCompany();
ClearPerson();

comboCompanyCompany.SelectedIndex = -1;
comboCompanyCompany.Items.Clear();

comboPersonCompany.SelectedIndex = -1;
comboPersonCompany.Items.Clear();

CutPasteImage = null;
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */
