﻿/*******************************************************************************
File        : PersonWI.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using Wiker.WIDatabase;
using System.Collections.ObjectModel;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm
{
/*******************************************************************************
Function    : NewPersonWI()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool NewPersonWI(stPerson person)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Save Person Address */
if (!SaveAddressWI(WIDB, person.Address))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Person Photo If Exists */
if (person.PhotoImage != null)
   {
   if (!SaveImageWI(WIDB, person.PhotoImage, out person.PhotoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Save Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/* Save Person Infomation */
if (!SavePersonWI(WIDB, person))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Person\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Save Person Home Phone  */
if (!SavePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Home, person.PhoneHome))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Home Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Person Work Phone  */
if (!SavePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Work, person.PhoneWork))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Cell Person Phone  */
if (!SavePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Cell, person.PhoneCell))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Cell Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Fax Person Phone  */
if (!SavePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Fax, person.PhoneFax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Fax Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Other Person Phone  */
if (!SavePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Other, person.PhoneOther))
   {
   WIDB.Close();
   Str = string.Format("Failed to Save Other Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : SavePersonWI()
Description : 
Parameters  : WIDatabase db - 
            : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SavePersonWI(WIDatabase db, stPerson person)
{
db.Insert.Clear();
db.Insert.Table("tblPerson");

db.Insert.Column("Name", person.Name);
db.Insert.Column("Active", person.Active);
db.Insert.Column("AddressID", person.Address.AddressID);
db.Insert.Column("CompanyID", person.Company.CompanyID);
db.Insert.Column("PhotoID", person.PhotoID);

if (!db.Insert.Execute(out person.PersonID))
   return(false);

return(true);
}
/*******************************************************************************
Function    : UpdatePersonWI()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdatePersonWI(stPerson person)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Person Address */
if (!UpdateAddressWI(WIDB, person.Address))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Person Photo If Exists */
if (person.PhotoImage != null)
   {
   if (person.PhotoID > 0) /* Update Existing Image */
      {
      if (!UpdateImageWI(WIDB, person.PhotoImage, person.PhotoID))
         {
         WIDB.Close();
         Str = string.Format("Failed to Update Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
            WIDB.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }

   else
      { /* New Image */
      if (!SaveImageWI(WIDB, person.PhotoImage, out person.PhotoID))
         {
         WIDB.Close();
         Str = string.Format("Failed to Save Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
            WIDB.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }
   }

else
if (person.PhotoID > 0) /* Delete Existing Image */
   {
   if (!DeleteImageWI(WIDB, person.PhotoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/*----------------------------------------------------------------------------*/

/* Update Person Infomation */
if (!UpdatePersonWI(WIDB, person))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Person\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Person Home Phone */
if (!UpdatePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Home, person.PhoneHome))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Home Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Person Work Phone */
if (!UpdatePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Work, person.PhoneWork))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Cell Person Phone */
if (!UpdatePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Cell, person.PhoneCell))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Cell Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Fax Person Phone */
if (!UpdatePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Fax, person.PhoneFax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Fax Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Other Person Phone */
if (!UpdatePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Other, person.PhoneOther))
   {
   WIDB.Close();
   Str = string.Format("Failed to Update Other Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }
WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : UpdatePersonWI()
Description : 
Parameters  : WIDatabase db - 
            : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdatePersonWI(WIDatabase db, stPerson person)
{
bool Result;

if (person == null || person.PersonID < 1)
   return(false);

db.Update.Clear();
db.Update.Table("tblPerson");

db.Update.Column("Name", person.Name);
db.Update.Column("Active", person.Active);
db.Update.Column("AddressID", person.Address.AddressID);
db.Update.Column("CompanyID", person.Company.CompanyID);
db.Update.Column("PhotoID", person.PhotoID);

db.Update.Condition("PersonID", eOperator.Equal, person.PersonID);

Result = db.Update.Execute();

return(Result);
}
/*******************************************************************************
Function    : LoadPersonNamesWI()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool LoadPersonNamesWI()
{
WIDatabase WIDB;
string Str;
stPerson Person;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/* Build Select Request */
WIDB.Search.Column("PersonID");
WIDB.Search.Column("Name");
WIDB.Search.Table("tblPerson");
WIDB.Search.Sort("Name", eSort.Ascending);

if (!WIDB.Search.Execute()) /* Build/Check Select Statement */
   {
   Str = string.Format("Failed to search tblPerson\nLastError = {0}\n{1}", WIDB.LastError,
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

while (WIDB.Search.Read()) /* Loop Through Results */
   {
   Person = new stPerson();
   WIDB.Search.Get("Name", out Person.Name);
   WIDB.Search.Get("PersonID", out Person.PersonID);

   /* Add Person Names To ComboBox */
   comboPersonPerson.Items.Add(new stComboItem(Person.Name, Person));
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : SearchPersonWI()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SearchPersonWI(stPerson person)
{
WIDatabase WIDB;
Collection<CCondition> Conditions;
string Str;

if (person == null || person.PersonID < 1)
   return(false);

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

WIDB.Search.Clear();
WIDB.Search.Column("tblPerson", "PersonID");
WIDB.Search.Column("tblPerson", "AddressID");
WIDB.Search.Column("tblPerson", "CompanyID");
WIDB.Search.Column("tblPerson", "Name");
WIDB.Search.Column("PhotoID");
WIDB.Search.Column("tblPerson", "Active");
WIDB.Search.Column("Address1");
WIDB.Search.Column("Address2");
WIDB.Search.Column("City");
WIDB.Search.Column("State");
WIDB.Search.Column("ZipCode");
WIDB.Search.Column("ImageData");
WIDB.Search.Column("tblCompany", "Name", "CompanyName");
WIDB.Search.Column("P1", "Number", "PhoneHome");
WIDB.Search.Column("P2", "Number", "PhoneWork");
WIDB.Search.Column("P3", "Number", "PhoneCell");
WIDB.Search.Column("P4", "Number", "PhoneFax");
WIDB.Search.Column("P5", "Number", "PhoneOther");

WIDB.Search.Table("tblPerson");

/*----------------------------------------------------------------------------*/

WIDB.Search.Condition("tblPerson", "PersonID", eOperator.Equal, person.PersonID);

WIDB.Search.Join("tblAddress", "AddressID", eOperator.Equal, "tblPerson", "AddressID", eJoinType.Left);
WIDB.Search.Join("tblImage", "ImageID", eOperator.Equal, "tblPerson", "PhotoID", eJoinType.Left);
WIDB.Search.Join("tblCompany", "CompanyID", eOperator.Equal, "tblPerson", "CompanyID", eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P1", "PersonID", eOperator.Equal, "tblPerson", "PersonID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P1", "Type", eOperator.Equal, (int)ePhoneType.Home));
WIDB.Search.Join("tblPhone", "P1", Conditions, eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P2", "PersonID", eOperator.Equal, "tblPerson", "PersonID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P2", "Type", eOperator.Equal, (int)ePhoneType.Work));
WIDB.Search.Join("tblPhone", "P2", Conditions, eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P3", "PersonID", eOperator.Equal, "tblPerson", "PersonID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P3", "Type", eOperator.Equal, (int)ePhoneType.Cell));
WIDB.Search.Join("tblPhone", "P3", Conditions, eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P4", "PersonID", eOperator.Equal, "tblPerson", "PersonID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P4", "Type", eOperator.Equal, (int)ePhoneType.Fax));
WIDB.Search.Join("tblPhone", "P4", Conditions, eJoinType.Left);

Conditions = new Collection<CCondition>();
Conditions.Add(new CCondition("P5", "PersonID", eOperator.Equal, "tblPerson", "PersonID"));
Conditions.Add(new CCondition(eLogic.AND));
Conditions.Add(new CCondition("P5", "Type", eOperator.Equal, (int)ePhoneType.Other));
WIDB.Search.Join("tblPhone", "P5", Conditions, eJoinType.Left);

/*----------------------------------------------------------------------------*/

if (!WIDB.Search.Execute()) /* Build/Check Select Statement */
   {
   Str = string.Format("Failed to search tblPerson\nLastError = {0}\n{1}", WIDB.LastError,
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!WIDB.Search.Read()) /* Loop Through Results */
   {
   WIDB.Close();
   return(false);
   }

/*----------------------------------------------------------------------------*/

WIDB.Search.Clear();
WIDB.Search.Get("PersonID", out person.PersonID);
WIDB.Search.Get("AddressID", out person.Address.AddressID);
WIDB.Search.Get("CompanyID", out person.Company.CompanyID);
WIDB.Search.Get("Name", out person.Name);
WIDB.Search.Get("CompanyName", out person.Company.Name);
WIDB.Search.Get("PhotoID", out person.PhotoID);
WIDB.Search.Get("Active", out person.Active);

WIDB.Search.Get("Address1", out person.Address.Address1);
WIDB.Search.Get("Address2", out person.Address.Address2);
WIDB.Search.Get("City", out person.Address.City);
WIDB.Search.Get("State", out person.Address.State);
WIDB.Search.Get("ZipCode", out person.Address.ZipCode);

WIDB.Search.Get("ImageData", out person.PhotoImage);
WIDB.Search.Get("PhoneHome", out person.PhoneHome);
WIDB.Search.Get("PhoneWork", out person.PhoneWork);
WIDB.Search.Get("PhoneCell", out person.PhoneCell);
WIDB.Search.Get("PhoneFax", out person.PhoneFax);
WIDB.Search.Get("PhoneOther", out person.PhoneOther);

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : DeletePersonWI()
Description : 
Parameters  : stPerson person - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeletePersonWI(stPerson person)
{
string Str;
WIDatabase WIDB;

/* Create Connection And Open Database */
WIDB = new WIDatabase(GetDBInfo());

if (WIDB.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(WIDB.DatabaseType),
      WIDB.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

if (person.Address.AddressID > 0)
   {
   if (!DeleteAddressWI(WIDB, person.Address))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Address\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

if (person.PhotoID > 0)
   {
   if (!DeleteImageWI(WIDB, person.PhotoID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Image\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/*----------------------------------------------------------------------------*/

if (!DeletePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Home))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Home Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Work))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Work Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Cell))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Cell Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Fax))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Fax Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneWI(WIDB, 0, person.PersonID, ePhoneType.Other))
   {
   WIDB.Close();
   Str = string.Format("Failed to Delete Other Phone\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
      WIDB.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

if (person.PersonID > 0)
   {
   if (!DeletePersonWI(WIDB, person.PersonID))
      {
      WIDB.Close();
      Str = string.Format("Failed to Delete Person\nLastError = {0}\n{1}", WIDB.LastError.ToString(),
         WIDB.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

WIDB.Close();

return(true);
}
/*******************************************************************************
Function    : DeletePersonWI()
Description : 
Parameters  : WIDatabase db - 
            : int personID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeletePersonWI(WIDatabase db, int personID)
{
bool Result;

if (personID < 1)
   return(false);

db.Delete.Clear();
db.Delete.Table("tblPerson");
db.Delete.Condition("PersonID", eOperator.Equal, personID);

Result = db.Delete.Execute();

return(Result);
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */